package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````I18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'`$?0``!'T```1]```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````0?0``$'T```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`^?B>K:&--UX?#E!K)1$ANYQTU*0$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/JA;&"93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)O@IP(*:AJ>4+_:5QNCX/M)````
M``````````````````````#4$0````````,`"P```````)`````````#`!8`
M$P(`````````````$@```/L``````````````!(```#=`@`````````````2
M````J`(`````````````$@```)H"`````````````!(```"6````````````
M```2````=`$`````````````$@```!$!`````````````!(````!````````
M```````@````DP(`````````````$@```$(!`````````````!(````R`0``
M```````````2````H0(`````````````$@```"0!`````````````!(```#<
M`0`````````````2````$```````````````(````)(!`````````````!(`
M``"P`@`````````````2``````$`````````````$@````<"````````````
M`!(```"W`@`````````````2````+```````````````(````%T"````````
M`````!(```!&```````````````2````8P``````````````%@```&0!````
M`````````!(```!V```````````````2````TP``````````````$@```(<`
M`````````````!(```#Z`0`````````````2````Y`$`````````````$@``
M`+X"`````````````!(```#'`P`````````````2````MP``````````````
M$@```.T"`````````````!$```#5`0`````````````2````!P,`````````
M````$0```!D"`````````````!(````,`@`````````````2````5@$`````
M````````$@```,P!`````````````!(```#D```````````````2````Q0$`
M````````````$@````4!`````````````!(```"S`0`````````````2````
MBP$`````````````$@```)T!`````````````!(```!.`@`````````````2
M````\P$`````````````$@````$"`````````````!(```!<`@``````````
M```2````ZP$`````````````$@```/4"`````````````!(```"B````````
M```````2````*`(`````````````$@```'\!`````````````!(````O`@``
M```````````2````ZP(`````````````$0```'8"`````````````!$```#&
M```````````````1````NP$`````````````$@```$`"`````````````!(`
M``#C`@`````````````2````2P$`````````````$@```#@"````````````
M`!(```!4```````````````2````9`(`````````````$@```'T"````````
M`````!(```#%`@`````````````2````K@$`````````````$@```,P"````
M`````````!(```"$`@`````````````B````(@0``%R0````````$``7`-`#
M``#-+0``S````!(`#0!'!```'2<``-`$```2``T`<0(``.$4``#$`0``$@`-
M`$<#``!]'0``!````!(`#0!E`P``[2L``.`!```2``T`^`,``$B0````````
M$``7`&T$``"!'0``L`$``!(`#0`M!```2)`````````0`!<`6`,``#$?```D
M````$@`-`'L#```9)```;````!(`#0#<`P``$#L```0````1``\`!@0``$DY
M``#D````$@`-`!$$``"!'```/````!(`#0`9!```7)`````````0`!<`0@0`
M`%R0````````$``7`%L$```Q)@``[````!(`#0"$!```A20``%0````2``T`
MZP,```"0````````$``6`)\#``!5'P``'`$``!(`#0!4!```2)`````````0
M`!8`>@0``$20```$````$0`6`/$#``"E%@```````!(`#0`Y!```R3@``(``
M```2``T`[0,```"0````````(``6`+4#```5)@``'````!(`#0")`P``O1P`
M`,`````2``T`JP,``"TZ``#*````$@`-`"$$``!<D````````!``%P",!```
M<2```*@#```2``T``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R
M964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D
M97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S
M>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F86EL`&5X:70`;'-E
M96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P96XV-`!S=')R8VAR
M`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!S=')S
M='(`;6MD:7(`7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL
M;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C
M7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C
M:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y
M`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I
M<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E
M<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N<V\N,P!P87)?
M8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I
M<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7V)S<U]S
M=&%R=%]?`'-H85]U<&1A=&4`>'-?:6YI=`!?7V5N9%]?`%]?8G-S7V5N9%]?
M`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T
M80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A
M<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,T`$=,24)#
M7S(N,S,```````````(``0`"``(``@`!``$``0`!``(``0`!``(``0`"``$`
M`0`"``(``@`"``$``P`!``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"
M``$``@`!``(``0`"``(``@`"``(``@`#``(``@`!``(``0`"``(``@`!``(`
M`@`"``$``@`!``4``@`"``(``@`"``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`S`P``
M$````"`````4:6D-```$`)D$`````````0`#`"D#```0`````````+21E@8`
M``4`HP0``!````"SD98&```#`*X$```0````%&EI#0```@"9!````````+R-
M```7````P(T``!<```#\CP``%P````20```7````%)```!<````8D```%P``
M`""0```7````))```!<````HD```%P```"R0```7````,)```!<````XD```
M%P```#R0```7````1)```!<```#,CP``%0H``-"/```5"P``U(\``!42``#8
MCP``%1@``-R/```3&P``X(\``!4<``#DCP``%1T``.B/```5)0``[(\``!4G
M``#PCP``%3T``/2/```5/@``^(\``!5*``#8C@``%@,``-R.```6!```X(X`
M`!8%``#DC@``%@8``.B.```6!P``[(X``!8(``#PC@``%@D``/2.```6"P``
M^(X``!8,``#\C@``%@T```"/```6#@``!(\``!8/```(CP``%A````R/```6
M$0``$(\``!83```4CP``%A0``!B/```6%0``'(\``!86```@CP``%A<``"2/
M```6&0``*(\``!8:```LCP``%AX``#"/```6'P``-(\``!8@```XCP``%B$`
M`#R/```6(@``0(\``!8C``!$CP``%B0``$B/```6)@``3(\``!8H``!0CP``
M%BD``%2/```6*@``6(\``!8K``!<CP``%BP``&"/```6+0``9(\``!8N``!H
MCP``%B\``&R/```6,```<(\``!8Q``!TCP``%C(``'B/```6,P``?(\``!8T
M``"`CP``%C4``(2/```6-@``B(\``!8W``",CP``%C@``)"/```6.0``E(\`
M`!8Z``"8CP``%CL``)R/```6/P``H(\``!9```"DCP``%D$``*B/```60@``
MK(\``!9#``"PCP``%D0``+2/```610``N(\``!9&``"\CP``%D<``,"/```6
M2```Q(\``!9)``#(CP``%DH```A`+>D^`0#K"("]Z`3@+>4$X)_E#N"/X`CP
MON7<?````,:/X@?*C.+<_+SE`,:/X@?*C.+4_+SE`,:/X@?*C.+,_+SE`,:/
MX@?*C.+$_+SE`,:/X@?*C.*\_+SE`,:/X@?*C.*T_+SE`,:/X@?*C.*L_+SE
M`,:/X@?*C.*D_+SE`,:/X@?*C.*<_+SE`,:/X@?*C.*4_+SE`,:/X@?*C.*,
M_+SE`,:/X@?*C.*$_+SE`,:/X@?*C.)\_+SE`,:/X@?*C.)T_+SE`,:/X@?*
MC.)L_+SE`,:/X@?*C.)D_+SE>$?]YP#&C^('RHSB6/R\Y0#&C^('RHSB4/R\
MY0#&C^('RHSB2/R\Y0#&C^('RHSB0/R\Y0#&C^('RHSB./R\Y0#&C^('RHSB
M,/R\Y0#&C^('RHSB*/R\Y0#&C^('RHSB(/R\Y0#&C^('RHSB&/R\Y0#&C^('
MRHSB$/R\Y0#&C^('RHSB"/R\Y0#&C^('RHSB`/R\Y0#&C^('RHSB^/N\Y0#&
MC^('RHSB\/N\Y0#&C^('RHSBZ/N\Y0#&C^('RHSBX/N\Y0#&C^('RHSBV/N\
MY0#&C^('RHSBT/N\Y7A'_><`QH_B!\J,XL3[O.4`QH_B!\J,XKS[O.4`QH_B
M!\J,XK3[O.4`QH_B!\J,XJS[O.4`QH_B!\J,XJ3[O.4`QH_B!\J,XIS[O.4`
MQH_B!\J,XI3[O.4`QH_B!\J,XHS[O.4`QH_B!\J,XH3[O.4`QH_B!\J,XGS[
MO.5X1_WG`,:/X@?*C.)P^[SE`,:/X@?*C.)H^[SE`,:/X@?*C.)@^[SE`,:/
MX@?*C.)8^[SE`,:/X@?*C.)0^[SE`,:/X@?*C.)(^[SE`,:/X@?*C.)`^[SE
M`,:/X@?*C.(X^[SE>$?]YP#&C^('RHSB+/N\Y0#&C^('RHSB)/N\Y0#&C^('
MRHSB'/N\Y0#&C^('RHSB%/N\Y0#&C^('RHSB#/N\Y0#&C^('RHSB!/N\Y0#&
MC^('RHSB_/J\Y0#&C^('RHSB]/J\Y0#&C^('RHSB[/J\Y7"U3_2`7*WK#`S,
M^,@/6TV*L%M+?41;3,WI!A`&J062!Z@%JGQ$ZU@;:`F33_```__WO.]42E5+
MHE@#DA%&XU@$DQA&`O#H^E%+XU@<>``L8]`=[G`O1TL'G7M$&V@H'0,UL/&`
M3])8DOC&,T/P`P."^,8S=-*``/_W;.]%2@:<`T9Z1$1)>4108")H&F!#2@>8
M>D3:8$)*`2@):'I$F6!:8%_=(1T$ZX`.`_$,#%'X!$M,^`1/CD7YT0,P.4P`
M(0"1*D9\1$/X(!`W2>!H>43_]T3N`"@QT#1-"*Y]1.AH__?4[@1&,D@Q1GA$
M`/#H^$"S,$M[1-AH__<2[O_WA.XM2A]+>D336!IH"9M:0$_P``,LT2!&"K!P
MO?_W4.XG2GI$T&``L__W?.X32QWN<"][1!MHTUB#^'M'C.?@:/_W(.[)YZAH
M$+$!\-#[T><<2#%&>$0`\+3XJ&``*,G0\^?_]Z#N!""IYP$@__<X[__WNNX`
MOYYZ``#(>0``U'D``"`!``#$>0````$``!@!```H`0``YGH``-IZ``!.*0``
M0"D``*1Z``!7!@``C'H``)HF``!T>@``Y'@``$AZ``#.)0``3_``"T_P``X"
MO&I&!+0!M-_X&*`%HYI$3_```PBT!$A:^```__?F[O_WGNW\=P``,`$``!0P
MG^44()_E`S"/X`(@D^<``%+C'O\O`=3^_^KD=P``!`$```9(!TL'2GA$>T1Z
M1(-"`]`%2]-8`[$81W!'`+]">0``0'D``,)W```(`0``"$@)2WA$"4I[1!L:
M>D39#P'KHP%)$`/0!4O36`.Q&$=P1P"_&'D``!1Y``"4=P``#`$```BU"DL*
M2GM$>D0;>&NY"4O36".Q"$M[1!AH__>N[O_WO_\&2P$B>T0:<`B]XG@``&1W
M```L`0``CG@``,)X``#$YP"_+>GX0T_T@%RMZPP,S/C@#Q]+@$9[1``H-M`>
M2IM8T_@`D+GQ``\QT`5X#T8`+1B_/2T4OP$E`"43T=GX`$!LL4Y&*D9!1B!&
M__<\[A"Y8UT]*Q#05O@$3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"`7A
MYZ;K"08!-2Q$MA`^8"!&O>CX@P1&Y^=,1N7G%'<``!P!```0M4_T@%RMZPP,
MS/B(#Q=*G+`72VE&>D0$1M-8&V@;DT_P``/_]\KMH+D$FP/T<$.S]2!/&+^S
M]8!/#=`-2@Q+>D336!IH&YM:0$_P``,+T1RP$+T`(/'G`B$@1O_W'.VP^H#P
M0`GIY__WD.UZ=@``(`$``%!V``#PM4_T@%RMZPP,S/AP#S9*G[`V2WI$TU@;
M:!V33_```Q"Q`W@$1ENY,4HP2WI$TU@::!V;6D!/\``#4]$?L/"]__>2[`5&
M`"CNT"A&__>F[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0($;_]_;L!T8P
M1O_W\NPX1`(P__=$[1Q+3_#_,@$A>T0!E@"4!D;_]XKM`JDP1O_WR.P!,#!&
M!=`&FP/T<$.S]8!/%]#_]]SL,$;_]ZCL*$;_]W#M`"C(T2A&__<`[2!&__<V
M[:OG<W@N*\G1LW@`*[;0Q>?_]X__YN?_]Q;M!'8``"`!``#L=0``:"(``"WI
M\$=/](!<K>L,#,SXV`]72H*P5TL,1GI$!4;?^%B!TUCX1!MH`9-/\``#"W@]
M*PB_`30@1O_WENQI1@9&*$;_]]K^@48`*%30__>,[(9"1]E*2P"?6/@#@+\`
M*W@`*QB_/2L4OP$C`",'T"M&$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WQ.SP
M4>BQV/@`,"A&V5D0^`$["W`]*QB_`"L)T$H<$/@!.Q%&`O@!.STK&+\`*_;1
M"D8](PMP%/@!.P+X`3\`*_G1+4HJ2WI$TU@::`&;6D!/\``#1M$"L+WH\(<)
M\?\Y%/@!.PGX`3\`*_G1Z><A2UCX`X#8^`!P.VB#LSM&4_@$+TE&"?$!"0`J
M^-$#,8D`&TIZ1!-HN[D(1@$C$V#_]W3L@D8`*,S0.49/ZHD'.D;_]Y#LR/@`
MH,WX`)`)\0$)`"-*^"DPAN<X1O_WPNR"1LCX````*+303^J)!^SGF48((=7G
M__=8[`"_"'4``"`!``#^=```'`$``%1T``"(=0``+>GP04_T@%RMZPP,S/@`
M`$SX(`P/1BQ)+$NM]8!=>42"L`9&#?6`4`0P#?$$",M80/;_<D%&&V@#8$_P
M``,D2'A$__=F[`0>!]T"K6,>!>L##!SX!"SJN=NY&4L=[G`/.D8Q1GM$&VC`
M6/_W=.L92@WU@%$52P0Q>D336!IH"VA:0$_P``,8T0WU@%T"L+WH\($<1B)&
M+R%`1O_W;.P`*-O0"$@=[G!?(T9"1GA$`&@Q1BA8__>JZ]GG__?LZP"_1'0`
M`/QS``!Z<P``(`$``#@@```@<P``,+5/](!<K>L,#,SXX`\32AWN<$\/286P
M$4AZ1'E$"6@02P`E>T026&!8#TD#DGE$__<<[`A)#4MY1`EH#$I[1'I$8%@+
M20&5>40`D__W3NL%L#"]M',``)AS``"F<@``%`$``#!@``""'P``<B(``*$/
M``"$'P``"DJ"L`I)'>YPSWI$!D@)2WA$`&A26'M$!TE<^```>40!D@*P__?D
MNTAS```^<@``%`$``,9?```:'P``<+5/](!<K>L,#,SX``"L]8!<S/@``$SX
M*`PD2JWU`%TC2X:P>D0-]0!1%#$#K`WU@%;36!`V&V@+8$_P``/_]Y;K'$H!
M(1Q+>D3-Z0`">T0@1D'R`0+_]Z+K($9/](!2,4;_]Y#K!!ZXOP`E"MM@'/_W
M1.L%1BBQ(D8Q1O_W].H`(RM5#4H-]0!1"4L4,7I$TU@::`MH6D!/\``#!-$H
M1@WU`%T&L'"]__<NZ^AQ```@`0``]!X``.(>``!^<0``__>>ORWI\$]/](!<
MK>L,#,SX``!,^*@,6DJM]81=6DN!L'I$!D992`WU@U4-\1`('#736`Q&>$1!
M1AMH*V!/\``#__?O_"\A!48P1O_W1.K`L4](,49X1/_WZ/TP1DU*#?6#44A+
M'#%Z1--8&F@+:%I`3_```T#P@X`-]81=`;"]Z/"/($;_]\CJ0TEY1/_WZ.H$
M1@`HW-`C>`WQ@`K?^/R0JO$$!_E$`"M(T"6Q(48H1O_W0.NXLR!&__=JZD,>
M(T2#1IQ"/K\C&``A8!P#TPK@F$(9<`/0$_@!+2\J^-`@1O_W5NJ#1C!&__=2
MZEA$`3"P]8!?K-(I2`$A2T9/](!2>$0`E,WI`08X1O_WYNI!1CA&__<DZC"Y
M6OA@/`/T<$.S]0!/%]`>20`@>43_]YCJ!$8`*(S0(W@`*[;1U;$K>"XK!-`8
M3$_P`0M\1,OG:W@`*^C0]N<!(3A&__?ZZ0`HX=$12#E&>$3_]U_].$;_]U+J
M<^<.3$_P`0M\1+/G__=BZBIQ```@`0``3AX``#H>``#D<```%!X``/X=``"J
M'0``=!T``#0=```H'0``!!T``!"U3_2`7*WK#`S,^/@/+R$$1O_WIND`L40<
M($:]Z!!`__<>NO"U3_2`7*WK#`S,^```3/@@##M*K?6`73I+@[!Z1`WU@%$$
M,=-8&V@+8$_P``,`*#S0`W@%1@`K.-#_][[I0AP$1K+U@%]'V`&O*48X1O_W
MP.EC'CM$GT(+TC@9#?$%`@`A`N"00@%P`]`0^`$]+ROXT"\A.$;_]V+I>+.X
M0H2_`",#<#A&__?<Z1]*#?6`41Q+!#%Z1--8&F@+:%I`3_```RO1#?6`70.P
M\+T72@WU@%$42P0Q>D336!IH"VA:0$_P``,:T1)(>$0-]8!=`["]Z/!`__>R
MN0`@UN<-2@WU@%$(2P0Q>D336!IH"VA:0$_P``,"T0A(>$3FY__WN.E8;P``
M(`$``.!N``"^;@``X!L``(YN``"P&P``<+5/](!<K>L,#,SXZ`_,2H*PS$ML
M1GI$RT[,37Y$TUA]1!MH`9-/\``#(48P1O_W?_NPL<9+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=I^P`HZ-&\3GY$(48P1O_W8?NP
ML;=+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=+^P`H
MZ-&N3GY$(48P1O_W0_NPL:A+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__<M^P`HZ-&@3GY$(48P1O_W)?NPL9E+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__</^P`HZ-&23GY$(48P1O_W!_NP
ML8I+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?Q^@`H
MZ-&$3GY$(48P1O_WZ?JPL7M+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__?3^@`HZ-%V3GY$(48P1O_WR_JPL6Q+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>U^@`HZ-%H3GY$(48P1O_WK?JP
ML5U+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>7^@`H
MZ-%:3GY$(48P1O_WC_JPL4Y+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$
M*P`J^M$A1C!&__=Y^@`HZ-%,3GY$(48P1O_W<?JPL3]+`)CK6!EH`>N``UIH
M0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=;^@`HZ-$^3GY$(48P1O_W4_JP
ML3!+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<]^@`H
MZ-$P2"%&>$3_]S;Z`488L2U(>$3_]S3[+$@A1GA$__<K^@%&&+$J2'A$__<I
M^RE((49X1/_W(/H!1K"Q)DAX1/_W'OLE2A%+>D336!IH`9M:0$_P``,5T2%)
M(DAY1'A$`K"]Z'!`__<+NQ]((49X1/_W`OH!1@`HY-`<2'A$__?_^M_G__<*
MZ$)N```@`0``H!L``#AN```<`0``9!L``#`;````&P``S!H``*`:````&@``
M-!H```0:``#4&0``'!D``&89``!"&0``9!D``&P9``!N&0``FA@``%AK``#,
M&@``SA@``$(9``#,&````+5/](!<K>L,#,SX\`\32H.P$TMI1GI$$DAX1--8
M&V@!DT_P``/_]Z_Y0+$`>``H&+\P*`R_`2``((#P`0`*2@=+>D336!IH`9M:
M0$_P``,"T0.P7?@$^_[WJ.^::@``(`$``#X8``!N:@``#[1/](!<`+6MZPP,
MS/CP#]_X,,"#L`Q*!*O\1`M)#$AY1%SX`B`2:`&23_```E/X!"L`DPA8`2$`
M:/[W2N__(/[W^N\J:@``(`$``"1J```D`0``+>GP1T_P``Q/](`^K>L,#*SK
M#@ZL]8!<S/@``/1%^=%.^#@,K?6`/8:P/DP"(0WU@#5\1!0U`)$`(CM)`".`
M1F%8"6@I8$_P``'^]T3O`3AA\0`'^A>`Z@(#FQJ;LE-`FQIBZP("QAIGZP('
M`"]+VT_P"`G`\@$)`ZT`(3)&.T9`1@"1_O<F[['Q_S\(O[#Q_S]!T$I&*49`
M1O[WJ.Y#'#;0!R@FV0@X+!@CTM_X?*#Z1`+@`3RL0AS3"")11B!&_O=$[@`H
M]=%D&Z`91^OD<1=*#?6`-!1+%#1Z1--8&F@C:%I`3_```QK1#?6`/0:PO>CP
MA[;U@#9G\0`'M_'_/PB_%O6`/[C13_#_,`%&W^<(2'A$__=*_P=(>$3_]T;_
M_O?D[KYI```@`0``?&H``!9I```2%P``^A8```BU3_2`7*WK#`S,^/@/_O="
M[O[WA.X`L0!H"+WPM4_T@%RMZPP,S/C0#RY*A[`N2P5&>D0M3@2I?D336#!&
M&V@%DT_P``/_]Z'X$+$#>`1&B[DG2B1+>D336!IH!9M:0$_P``,\T2-(*49X
M1`>PO>CP0/_WC[DI1O[W:.Y8L1Y*&4MZ1--8&F@%FUI`3_```R;1![#PO2A&
M_O<N[@=&($;^]RKN.$0",/[W?.X32T_P_S(!(7M$`9,12P*4!$9[1`"5_O?`
M[@]*!TMZ1--8&F@%FUI`3_```P2_(48P1L70_O=F[H)H```@`0``O!8``%YH
M``"*%@``,F@``%05``!.%0``ZF<``"WI\$]/](!<K>L,#,SXZ`[?^#@4O;#?
M^#A4(J_?^#0D>41]1()&!?$,`P7Q&`PHK#`UBE@F1@WQE`G?^!RT$F@[DD_P
M``(-\2`(D^@'`(?H!P#[1+SH#P`/QISH`P"&Z`,`E>@'`(GH!P#\2$%&>$3_
M]PCX(+$#>`5&`"M`\&F!_O>$[?[WQNT`*`#PG8`&:``N`/"9@#!&_O>J[4``
M`3#^]_SM,7@%1@>0>;'?^+"3^40H1@"12T8!(4_P_S("-?[W/.X6^`$?`"GR
MT>5(>$0"X%3X!`^(L4%&_O?3_P5&`"CVT`-X`"OST/_W%_@`*._0*$;^]\#M
M!$:(N5?X!$MTL2-X`"L`\`^!($;_]P;X`"CST"!&_O>P[01&`"CMT"!&_O=F
M[0>=!D8H1O[W8.T&1`;R!$8P1O[WL.W*2P=&3_#_,GM$`I/(2P$A`Y5[1`&3
MQTL`E'M$_O?P[4_TX'$X1O[WNNP!,`71_O<@[@%H$2E`\."`048X1O[WKNT%
M1@`H.="[2=KX`#"[2EOX`0!Z1`"7`2$`:/[WC.T`)K=*K$MZ1--8&F@[FUI`
M3_```T#P1H$P1CVPO>CPC_[W7.T&1@`H0/"R@%GX!`M8L4%&_O=8_P`H]]`#
M>``K[M%9^`0+`"CST:9.#2#^]UCM4R$%1GY$!Y!9YPR;`_1P0[/U@$^_T0Z<
M_O?"[(1"NM$,F\/S"`.S]>!_M-$P1O[W/NT&1IA(049X1/[W+/\!1@`H`/"A
M@-KX``#_]Q3Z@48`*`#PF8!(1O[WU.P$1@,H#]F-200X2$1Y1/[WG.U`N00L
M`/#9@$Q$%/@%/"\K`/#3@(9(049X1/[W!?\@L0-X,"L8OP`K!M$`(4A&_O?0
M[`1&`"AST7Y)?TAY1-_X_*%X1-_X^)'^]_+_W_CT@?[W+NU\2T_P_S(!(7M$
M`Y-Z2_I$`)?Y1'M$S>D!,'A+,$;X1'M$_O<T[1/@_O=H[0-H$2L6T?[W%.T!
M-81&4T8B1@$A,$;-Z0-9S>D!C`"7_O<>[4_TX'$P1O[WZ.L$1D,<X]`X1O[W
M1.QF2#%&>$3^][;_,$;_]_?].N<<1OGF_O=@[$```3"TYD]*VO@`,%OX`@#-
MZ0!Q`2%;2@!H>D3^][+L).?_]]_]6$H^2WI$TU@::#N;6D!/\``#:M$H1CVP
MO>CP3_[W?[S:^`"08^?_]Q[]@$:Q\0`)A=NP\0H"3_``"FGQ``,@1@WQN`O-
M^`"@_O=X[`8B648@1O[W_NL&*$G1+II/](9#Q/)!,YI"?_1JK[OX!"!$\DA3
MFD)_]&.ON/$R`B!&:?$``S"MS?@`H/[W6.P@1B@B*4;^]][K*"@IT3)+`2$R
M2C!&>T0!DS%+>D0"E0.2>T1/\/\R`)>-^.B@_O>4['SGVO@$0``L/_0HKR!&
M_O?FZP,H?_8BKR9)!#@@1'E$_O>N[``H"+^A1A?G_O<R["%(>$3_]X[\C&<`
M`,9H```@`0``6F<``'84``!4%0``TA0``-04``"^$P``MA0``"0!``#,%```
M"F8```H4``"*%```8A0``.`2``"<%```MA(``#84``#:%```/A(``.04``!(
M$@``%!0``,H1``#6$@``4F0``!01``">$P``T!(``(X2``""$@``<+5/](!<
MK>L,#,SXZ`]D28*P9$H=[G!/>4192V)(;D:*6'A$,482:`&23_```GM$&VCE
M6)7X:#"%^&DP_O>Z_1"Q`W@Q*WS0__<<^DU+>T0;:.5854DH1@,C`2)Y1/[W
M$.L%1G"Q`FE'2WM$&V@1:$]*X%AZ1/[W$.LK:1EHBVA;`FO404D#(P$B>40)
M:&!82$EY1/[W].H%1GBQ1D@Q1GA$_O>'_0)&`"A.T#A+*6E[1!MH"6C@6/[W
M[NHU2P$B/DE[1!MH>43E6"A&_O>ZZCM*`48H1GI$.DW^]][J+DLY2'U$>T0;
M:``B>$0Q1N-8@_AI(/[W7OT$1JA@L+%/].!Q($;^]X#J0AP#1A$H&+\!*BS8
M+4HC2WI$TU@::`&;6D!/\``#(-$"L'"]:&C_]__\!$:H8``HX=$E2'A$_O=X
MZT-X`"N%T'[G(DLJ:7M$$&A;:!EH_O?U_J_G#TM[1!MHX%C^]R;KC.?^]S;K
M&DDB1AI(>41X1$EH"6C^]UCKOF,``)YC``""8P``8F,``#QC```J8P``"&,`
M`(YB``#$8@``(`$``$80``#<$0``R!$``+(1``"`#P``@A$``(H1``!Z8P``
M*@\``,1A```L$0``#F,``.AB```6$0``,+5/](!<K>L,#,SXZ`\I2@1&*4N#
ML'I$*$AI1GA$TU@;:`&33_```_[WU/QPL0-X`"L8OS`K#+\!(P`C@_`!`P`L
M#+\`(P/P`0-;N1Q*&DMZ1--8&F@!FUI`3_```R?1`[`PO2-X`"OPT"!&__>,
M^"\A!4;^]R;J`+%%'"A&_O>DZA!)!")Y1/[W!NL`*-W1#4H)2WI$TU@::`&;
M6D!/\``#!=$@1@.PO>@P0/[W&KW^]Z+JYF```"`!``"(#@``K&```.(.``!H
M8```+>GP3T_T@%RMZPP,S/@P#=_X$$JM]2M]`T8(J0/Q@`??^`0Z?$0"D`I&
M0#``)KQ&XU@;:*F33_```U#I`G168-9@$#(_ND+X$'PC"B4"`_1_0P@P0^H4
M8P7T?P5#Z@1C8$5#Z@4#0O@(/.;1W>DB@@JL)IL-\8@)`),DJ":M`?4"<P.0
M($8$E<WI!4$-:,WX')"11MWXE.#=^)S`"9_=^"RP))[=^"B@`)D!DP'@DD:;
M1@"1`"/0Z0X44/@(+T-G44"!Z@@!L$9#:&E``)Y51EQ`A.H)!/%&?$#F1D_J
MT7Q)&$SJ1`P!G$'J#`%?1D_P``R$0@%GVM$#FP*8W>D%01UH!)O0Z0%[&V@#
MD]#I`SI/ZIL.T/@`P`IH(6A.ZH-^A&E']ID3Q?:"(P"4!&K2&$_JW&`!E$#J
M1Q`2&0"<0.I,$-WX')""&(KJ!`!.ZHM^`.H+`-WX,(!@0-GX`&`2&$_JG`F*
MZ@X`R1A)ZH=Y`.H,`$GJC'D)&8#J"@`.GP@8CNH)`1CK`P@10`#K\F`8ZPH(
M@>H.`4_JL@(8ZP$!_Q@7ZPX(`>OP9XGJ`@'=^$#@`4!/ZK``@>H)`1CK`0$>
MZP,.'NL)"0'K]VZ"Z@`!W?A(@#E`3^JW!U%`&>L!`1CK`P@8ZP()@.H'`MWX
M4(`"Z@X"`>O^84)`3^J^#AGK`@(8ZP,(&.L`"0+K\6"'Z@X"W?A8@`I`3^JQ
M`7I`&>L"`ACK`P@8ZP<)`NOP9X[J`0+=^&"``D!/ZK``@NH.`AGK`@(8ZP,(
M&.L."0+K]VZ!Z@`"W?AH@#I`3^JW!TI`&>L"`ACK`P@8ZP$)`NO^88#J!P+=
M^'"``NH.`D_JO@Y"0!GK`@(8ZP,(&.L`"0+K\6"'Z@X"W?AX@`I`3^JQ`7I`
M&>L"`ACK`P@8ZP<)`NOP9X[J`0+=^("``D!/ZK``@NH.`@.<&>L"`ACK`P@8
MZPX.`NOW:('J``(Z0$_JMP=*0![K`@+V&'88@.H'`0'J"`$"Z_AB04!/ZK@(
M<1CM&"T8`>OR8(?J"`$10$_JL@*(Z@(&>4!I&`9`*)WD&`'K\&&&Z@@&3^JP
M`.09I!F"Z@`'[1@/0!7K"`8JG03K\6170$_JL0'V&8#J`0[M&*\8#NH$#BR=
M3^JT`H[J``X&Z_1F%^L.!('J`@?M&#=`+1@NF$]`!.OV9.\93^JV!L,8,)U;
M&(+J!@$A0`?K]&Y10$_JM`18&$[VH3/&]MEC,ID5ZP,(`.O^8!CK`@B&Z@0"
M@NH.`D_JO@48ZP((A.H%#LH8-)\(Z_!ACNH`#I(93^JP`!+K#@(VGO\8A>H`
M#@+K\6*.Z@$./!E/ZK$!%.L.!#B?]AB`Z@$.!.OR9([J`@YU&4_JL@(5ZPX%
M.IZ!Z@(._QB.Z@0./Q@%Z_1@%^L.!T_JM`06ZP,./)T>ZP$.!^OP88+J!`='
M0$_JL``>ZP<.[Q@^GK\8#NOQ8H3J``Z.Z@$.3^JQ`1?K#@<6ZP,.0)T>ZP0.
M!^OR9(#J`0=70$_JL@(>ZP<.[QA"GC\8#NOT8('J`@Z.Z@0.3^JT!!?K#@=$
MG8+J!`[V&`?K\&>.Z@`.=AA/ZK``%NL.!D:9A.H`#NT8!NOW9H[J!PZM&$_J
MMP<5ZPX%2)K)&(#J!PX%Z_9ECNH&#@P93^JV!A3K#@1*F=(8A^H&#@3K]62.
MZ@4.$!A/ZK4%$.L.`$R:ANH%#LD8`.OT8([J!`[)&4_JM`01ZPX!3I^%Z@0.
MTA@!Z_!ACNH`#I(93^JP`!+K#@)0GO\8A.H`#@+K\6*.Z@$.?1E/ZK$!%>L.
M!5*?]AB`Z@$.CNH"#C09%.L.!`7K\F87ZP,.3^JR`E2='NL`#H'J`@`$Z_9D
M<$`>ZP`.3^JV`.T8@NH`!FD85IUF0`[K]&Z)&4_JM`3K&%B=FQB`Z@0"@NH.
M`D_JO@>:&$OVW$/(]AMS`>O^8>T81.H'#EJ>*!@.Z@$.!.H'!4[J!0X"Z_%B
M$.L.#D_JL0'P&%R=`!E'Z@$$#NOR9A1`!^H!#D_JL@)$Z@X$`>H"""08[1A!
MZ@(`%>L'#C!`!.OV95Z<0.H(`$_JM@80ZPX.X!@.Z_5D0!A"Z@8!`NH&#BE`
M8)]!Z@X!3^JU!0D8`>OT8/\81NH%`0;J!0ZZ&"%`8I]/ZK0$0>H.`07J!`B)
M&/\81>H$`A?K!@X"0&2?`>OP84+J"`)/ZK``$NL.`O\8!.H`#GT9`NOQ9T3J
M``)FG@I`3^JQ`4+J#@+=^*#A51GR&!(90.H!!$_JMP8%Z_=E/$``Z@$'/$-!
MZ@8'HA@>ZP,$)!@!Z@8.:I@O0`+K]6)'Z@X'3^JU!3P91NH%!\`8!.OR9`;J
M!0Y`&!=`3^JR`6R:1^H.!S\81>H!`-(8($"2&0?K]&8%Z@$'3^JT!#A#0>H$
M!X`8;IH!Z@0.-T#2&`#K]F!5&7":1^H.!T_JM@9_&=(851@'Z_!A1.H&!P3J
M!@YRF@=`1^H.!T_JL`!]&=(8$AE&Z@`$!NH`!PQ`/$,%Z_%EI!ATFD_JL0$$
MZ_5DTAA`Z@$'`.H!#I89+T!VFD?J#@=/ZK4%OQG2&!88!^OT8$'J!0<!Z@4.
M>)HG0$?J#@=/ZK0$OQE%Z@0&TA@&0%(8!^OP807J!`=/ZK``/D,"G[88`"($
MZ@`.!NOQ9GI@^F!ZFM(851D`(GIA^F%$Z@`'?)H/0$?J#@=/ZK$!?QG2&$#J
M`04'Z_9G$NL$#C5`3^JV!'Z:`.H!!C5#`>H$!A7K#@73&!L80>H$`#A`@)HP
M0P7K]V7`&$SRUA/,]F(C3^JW!]88@IIV&(3J!P%I0`#K]6!V&$_JM072&(?J
M!0$4&82:04`&Z_!F9!A/ZK``TAB%Z@`!UQF&F@3K]F1Q0'\83^JV!M$8B)I)
M&0?K]&6`Z@8'9T!/ZK0$R1G7&#\8BIJ&Z@0``>OU86A`3^JU!3\8T!B`&8R:
M!^OQ9H3J!0=/0$_JL0'`&=<8/QF.FH7J`00`Z_9@=$`_&4_JM@36&)":=AD'
MZ_!E@>H$!T=`3^JP`/89UQA_&)*:!NOU883J``9N0$_JM06_&=88-AF4F@?K
M\62`Z@4'3T!/ZK$!]AG7&#\8EIH&Z_1@A>H!!F9`3^JT!+\9UAAV&9B:!^OP
M98'J!`='0$_JL`#V&=<8?QB:F@;K]6&$Z@`&;D!/ZK4%OQG6&#89G)H'Z_%D
M@.H%!T]`3^JQ`?89UQ@_&)Z:!NOT8(7J`09F0$_JM`2_&=88=AF@F@?K\&6!
MZ@0'1T!/ZK``]AG2&%<8!NOU8:*:A.H`!FY`3^JU!;\9TA@6&0?K\62`Z@4'
MI)I/0$_JL0'W&0*>!^OT9](8$!@*Z[<",F&FFH7J`09F0$_JM`2`&=,8@>H$
M`@#K]V!Z0!/K#`,"GUL9FQ@0ZPL"`^OP8P"8.V`!FR08NF`,2LD8`"-[8@E+
M>D2\83EBTU@::*F;6D!/\``#`]$-]2M]O>CPC_WWANT`OPQ@```@`0``+E8`
M``BU3_2`7*WK#`S,^/@/@"#]]V[MG^T.>P`B@F>`[0![G^T->X#M`GN?[0U[
M@.T$>Y_M#7N`[09[G^T->X#M"'N?[0U[@.T*>X#M#'L(O0"_`2-%9P````")
MJ\WO`````/[<NI@`````=E0R$`````#PX=+#````````````````+>GX0T_T
M@%RMZPP,S/C@#P5&@&H61@`C#$8`Z\8,]Q>$1>AJU>D,(7/K```"T@$R0?$`
M`:AO!?$X",7I"L-S#T/JQP.;&"MC0>M7<6EC@+L_+D7=IO%`"4_JF19W'`3K
MAQ<A1D-&!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#
M^`0LZ]$,1BA&__=;^KQ"X=&IZX86,D8Y1D!&_?>8[*YGO>CX@\#Q0`<%\3@(
MMT)`1*B_-T8A1CI&_?>*[*MO.T2K9T`K[-$H1O8;/$3_]SGZM^<G1M[G+>GP
M04_T@%RMZPP,S/CH#XMJ`?$X!PIK#$:3^H/X!4;#\\4#%KI9'(`B."GZ5$7=
MP?%``G@8`"']]PCL($;_]Q7Z.$8X(@`A_?<`["!&Q.D<:/_W"_KC>"MP($9C
MB&MP(V@;"JMP(VCK<.-Z*W%CB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR
M(VGK<N-^*W-CBVMSHVD;"JMSHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP
M0?WWYKMX&,'Q.`(`(?WWPNO`YP"_`DM[1!MH_?>%O`"_!E4```A`+>D(@+WH
M`0`"`#X```!!````#````$$````1````00```"<```!!````-@```$$````#
M````00````8```!!````%0```$$````/````00````X```!!````)@```$$`
M```3````00```"D```!!`````@```$$````9````00````H```!!````"P``
M`$$``````````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O
M<')O8R\E:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````;'-E96L@9F%I;&5D````
M`')E860@9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````
M)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T
M92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET
M(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````
M+G!A<@````!S:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!
M4CHZ4&%C:V5R.CI615)324].`````#$N,#8Q````56YA8FQE('1O(&-R96%T
M92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M
M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<```
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*`'!E<FQX<VDN8P````!#04-(10``
M/@```$$````,````00```!$```!!````)P```$$````V````00````,```!!
M````!@```$$````5````00````\```!!````#@```$$````F````00```!,`
M``!!````*0```$$````"````00```!D```!!````"@```$$````+````00``
M````````````H)G_?P$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````)T7``!=%P```0```!D#```!````*0,```$````S`P``
M#````-01```-````"#L``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;[0!```%````,`D```8```"@`@``"@```+D$```+````$````!4`
M`````````P```,R.```"````Z`$``!0````1````%P```.P/```1````'`\`
M`!(```#0````$P````@````>````"````/O__V\!```(_O__;[P.``#___]O
M`@```/#__V_J#0``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````X!$``.`1``#@$0``X!$``.`1
M``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$`
M`.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``
MX!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@
M$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1
M``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$``.`1``#@$0``X!$`
M````````````````````````````````````````````````````````````
M`````.$4````````!)````I005(N<&T*`````.@^````/````````,`\``#$
M/```W#X```@\``#D/@```````,@^``#0/@```````/`^``!'0T,Z("A$96)I
M86X@,3,N,BXP+3DI(#$S+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!
M"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-
M+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN
M86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S
M``````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(``)`&
M```&`````P````0````0````1@````,````"````,`D``#`)``"Y!```````
M```````!`````````$X```#___]O`@```.H-``#J#0``T@````4`````````
M`@````(```!;````_O__;P(```"\#@``O`X``&`````&`````@````0`````
M````:@````D````"````'`\``!P/``#0````!0`````````$````"````',`
M```)````0@```.P/``#L#P``Z`$```4````5````!`````@```!\`````0``
M``8```#4$0``U!$```P```````````````0`````````=P````$````&````
MX!$``.`1`````P`````````````$````!````((````!````!@```.`4``#@
M%```*"8`````````````"`````````"(`````0````8````(.P``"#L```@`
M``````````````0`````````C@````$````"````$#L``!`[``#T00``````
M```````$`````````)8````!``!P@@````1]```$?0``"`````T`````````
M!`````````"A`````0````(````,?0``#'T```0```````````````0`````
M````JP````X````#````O(T``+Q]```$```````````````$````!````+<`
M```/`````P```,"-``#`?0``!```````````````!`````0```##````!@``
M``,```#$C0``Q'T```@!```&``````````0````(````S`````$````#````
MS(X``,Q^```T`0`````````````$````!````-$````!`````P````"0````
M@```2```````````````!`````````#7````"`````,```!(D```2(```!0`
M``````````````0`````````W`````$````P`````````$B````>````````
M```````!`````0```.4````#``!P``````````!F@```,P``````````````
M`0`````````!`````P``````````````F8```/4```````````````$`````
#````
